@@ -21,29 +21,7 @@ const COLORS = {
   }
 };
 
-function getNode(task) {
-  return {
-    id: task.id,
-    label: task.key,
-    shape: 'box',
-    borderWidth: 1,
-    color: {
-      border: COLORS[task.status]['border'],
-      background: COLORS[task.status]['background'],
-      highlight: {
-        background: COLORS[task.status]['background'],
-        border: COLORS[task.status]['hlborder'],
-      }
-    },
-    font: {
-      face: 'arial',
-      align: 'center',
-      color: '#fff',
-      strokeWidth: 0,
-      strokeColor: '#ffffff',
-    }
-  };
-}
+const REPO_LINK = "https://github.com/ovh/celery-director"
 
 const router = new VueRouter({
   mode: HISTORY_MODE ? 'history' : 'hash',
@@ -126,7 +104,6 @@ const store = new Vuex.Store({
         html += "<span class=details>" + tasks[i].status + "</span>";
         html += "</div>";
 
-        var color = COLORS[tasks[i].status]["background"];
         g.setNode(tasks[i].id, {
           labelType: "html",
           label: html,
@@ -220,7 +197,7 @@ new Vue({
           text: 'Status',
           align: 'left',
           value: 'status',
-          width: '15%',
+          width: '17%',
           filter: value => {
             if (this.selectedStatus.length == 0) return true
             return this.selectedStatus.includes(value)
@@ -230,7 +207,7 @@ new Vue({
           text: 'Name',
           align: 'left',
           value: 'fullname',
-          width: '60%',
+          width: '58%',
           filter: value => {
             if (!this.selectedWorkflowName || this.selectedWorkflowName == 'All') return true
             return value == this.selectedWorkflowName
@@ -258,6 +235,7 @@ new Vue({
     tab: null,
     payloadDialog: false,
     relaunchDialog: false,
+    repoLink: REPO_LINK,
     search: '',
     selectedStatus: [],
     status: ['success', 'error', 'progress', 'pending'],
